/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/buildbot/moz2-slave/mozilla-1.9.2-macosx-xulrunner/build/widget/public/nsIPrintSessionX.idl
 */

#ifndef __gen_nsIPrintSessionX_h__
#define __gen_nsIPrintSessionX_h__


#ifndef __gen_nsIPrintSession_h__
#include "nsIPrintSession.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
#include <Carbon/Carbon.h>

/* starting interface:    nsIPrintSessionX */
#define NS_IPRINTSESSIONX_IID_STR "2f977d54-5485-11d4-87e2-0010a4e75ef2"

#define NS_IPRINTSESSIONX_IID \
  {0x2f977d54, 0x5485, 0x11d4, \
    { 0x87, 0xe2, 0x00, 0x10, 0xa4, 0xe7, 0x5e, 0xf2 }}

/**
 * nsIPrintSessionX
 *
 * Stores a PMPrintSession
 *
 * @status
 */
class NS_NO_VTABLE nsIPrintSessionX : public nsIPrintSession {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IPRINTSESSIONX_IID)

  /**
   * nativeSession attribute
   *
   * Does NOT do PMRetain() on result.
   */
  /* readonly attribute nsPMPrintSession nativeSession; */
  NS_IMETHOD GetNativeSession(PMPrintSession *aNativeSession) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIPrintSessionX, NS_IPRINTSESSIONX_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIPRINTSESSIONX \
  NS_IMETHOD GetNativeSession(PMPrintSession *aNativeSession); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIPRINTSESSIONX(_to) \
  NS_IMETHOD GetNativeSession(PMPrintSession *aNativeSession) { return _to GetNativeSession(aNativeSession); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIPRINTSESSIONX(_to) \
  NS_IMETHOD GetNativeSession(PMPrintSession *aNativeSession) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNativeSession(aNativeSession); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsPrintSessionX : public nsIPrintSessionX
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIPRINTSESSIONX

  nsPrintSessionX();

private:
  ~nsPrintSessionX();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsPrintSessionX, nsIPrintSessionX)

nsPrintSessionX::nsPrintSessionX()
{
  /* member initializers and constructor code */
}

nsPrintSessionX::~nsPrintSessionX()
{
  /* destructor code */
}

/* readonly attribute nsPMPrintSession nativeSession; */
NS_IMETHODIMP nsPrintSessionX::GetNativeSession(PMPrintSession *aNativeSession)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIPrintSessionX_h__ */
